import { Duration, Resource } from '../../core';
import { Construct } from 'constructs';
/**
 * (experimental) Represents a response headers policy.
 *
 * @experimental
 */
export interface IResponseHeadersPolicy {
    /**
     * (experimental) The ID of the response headers policy.
     *
     * @experimental
     * @attribute true
     */
    readonly responseHeadersPolicyId: string;
}
/**
 * (experimental) Properties for creating a Response Headers Policy.
 *
 * @experimental
 */
export interface ResponseHeadersPolicyProps {
    /**
     * (experimental) A unique name to identify the response headers policy.
     *
     * @default - generated from the `id`
     * @experimental
     */
    readonly responseHeadersPolicyName?: string;
    /**
     * (experimental) A comment to describe the response headers policy.
     *
     * @default - no comment
     * @experimental
     */
    readonly comment?: string;
    /**
     * (experimental) A configuration for a set of HTTP response headers that are used for cross-origin resource sharing (CORS).
     *
     * @default - no cors behavior
     * @experimental
     */
    readonly corsBehavior?: ResponseHeadersCorsBehavior;
    /**
     * (experimental) A configuration for a set of custom HTTP response headers.
     *
     * @default - no custom headers behavior
     * @experimental
     */
    readonly customHeadersBehavior?: ResponseCustomHeadersBehavior;
    /**
     * (experimental) A configuration for a set of security-related HTTP response headers.
     *
     * @default - no security headers behavior
     * @experimental
     */
    readonly securityHeadersBehavior?: ResponseSecurityHeadersBehavior;
}
/**
 * (experimental) A Response Headers Policy configuration.
 *
 * @experimental
 * @resource AWS::CloudFront::ResponseHeadersPolicy
 */
export declare class ResponseHeadersPolicy extends Resource implements IResponseHeadersPolicy {
    /**
     * (experimental) Use this managed policy to allow simple CORS requests from any origin.
     *
     * @experimental
     */
    static readonly CORS_ALLOW_ALL_ORIGINS: IResponseHeadersPolicy;
    /**
     * (experimental) Use this managed policy to allow CORS requests from any origin, including preflight requests.
     *
     * @experimental
     */
    static readonly CORS_ALLOW_ALL_ORIGINS_WITH_PREFLIGHT: IResponseHeadersPolicy;
    /**
     * (experimental) Use this managed policy to add a set of security headers to all responses that CloudFront sends to viewers.
     *
     * @experimental
     */
    static readonly SECURITY_HEADERS: IResponseHeadersPolicy;
    /**
     * (experimental) Use this managed policy to allow simple CORS requests from any origin and add a set of security headers to all responses that CloudFront sends to viewers.
     *
     * @experimental
     */
    static readonly CORS_ALLOW_ALL_ORIGINS_AND_SECURITY_HEADERS: IResponseHeadersPolicy;
    /**
     * (experimental) Use this managed policy to allow CORS requests from any origin, including preflight requests, and add a set of security headers to all responses that CloudFront sends to viewers.
     *
     * @experimental
     */
    static readonly CORS_ALLOW_ALL_ORIGINS_WITH_PREFLIGHT_AND_SECURITY_HEADERS: IResponseHeadersPolicy;
    /**
     * (experimental) Import an existing Response Headers Policy from its ID.
     *
     * @experimental
     */
    static fromResponseHeadersPolicyId(scope: Construct, id: string, responseHeadersPolicyId: string): IResponseHeadersPolicy;
    private static fromManagedResponseHeadersPolicy;
    /**
     * (experimental) The ID of the response headers policy.
     *
     * @experimental
     */
    readonly responseHeadersPolicyId: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props?: ResponseHeadersPolicyProps);
    private _renderCorsConfig;
    private _renderCustomHeadersConfig;
    private _renderSecurityHeadersConfig;
}
/**
 * (experimental) Configuration for a set of HTTP response headers that are used for cross-origin resource sharing (CORS).
 *
 * CloudFront adds these headers to HTTP responses that it sends for CORS requests that match a cache behavior
 * associated with this response headers policy.
 *
 * @experimental
 */
export interface ResponseHeadersCorsBehavior {
    /**
     * (experimental) A Boolean that CloudFront uses as the value for the Access-Control-Allow-Credentials HTTP response header.
     *
     * @experimental
     */
    readonly accessControlAllowCredentials: boolean;
    /**
     * (experimental) A list of HTTP header names that CloudFront includes as values for the Access-Control-Allow-Headers HTTP response header.
     *
     * You can specify `['*']` to allow all headers.
     *
     * @experimental
     */
    readonly accessControlAllowHeaders: string[];
    /**
     * (experimental) A list of HTTP methods that CloudFront includes as values for the Access-Control-Allow-Methods HTTP response header.
     *
     * @experimental
     */
    readonly accessControlAllowMethods: string[];
    /**
     * (experimental) A list of origins (domain names) that CloudFront can use as the value for the Access-Control-Allow-Origin HTTP response header.
     *
     * You can specify `['*']` to allow all origins.
     *
     * @experimental
     */
    readonly accessControlAllowOrigins: string[];
    /**
     * (experimental) A list of HTTP headers that CloudFront includes as values for the Access-Control-Expose-Headers HTTP response header.
     *
     * You can specify `['*']` to expose all headers.
     *
     * @default - no headers exposed
     * @experimental
     */
    readonly accessControlExposeHeaders?: string[];
    /**
     * (experimental) A number that CloudFront uses as the value for the Access-Control-Max-Age HTTP response header.
     *
     * @default - no max age
     * @experimental
     */
    readonly accessControlMaxAge?: Duration;
    /**
     * (experimental) A Boolean that determines whether CloudFront overrides HTTP response headers received from the origin with the ones specified in this response headers policy.
     *
     * @experimental
     */
    readonly originOverride: boolean;
}
/**
 * (experimental) Configuration for a set of HTTP response headers that are sent for requests that match a cache behavior that’s associated with this response headers policy.
 *
 * @experimental
 */
export interface ResponseCustomHeadersBehavior {
    /**
     * (experimental) The list of HTTP response headers and their values.
     *
     * @experimental
     */
    readonly customHeaders: ResponseCustomHeader[];
}
/**
 * (experimental) An HTTP response header name and its value.
 *
 * CloudFront includes this header in HTTP responses that it sends for requests that match a cache behavior that’s associated with this response headers policy.
 *
 * @experimental
 */
export interface ResponseCustomHeader {
    /**
     * (experimental) The HTTP response header name.
     *
     * @experimental
     */
    readonly header: string;
    /**
     * (experimental) A Boolean that determines whether CloudFront overrides a response header with the same name received from the origin with the header specified here.
     *
     * @experimental
     */
    readonly override: boolean;
    /**
     * (experimental) The value for the HTTP response header.
     *
     * @experimental
     */
    readonly value: string;
}
/**
 * (experimental) Configuration for a set of security-related HTTP response headers.
 *
 * CloudFront adds these headers to HTTP responses that it sends for requests that match a cache behavior
 * associated with this response headers policy.
 *
 * @experimental
 */
export interface ResponseSecurityHeadersBehavior {
    /**
     * (experimental) The policy directives and their values that CloudFront includes as values for the Content-Security-Policy HTTP response header.
     *
     * @default - no content security policy
     * @experimental
     */
    readonly contentSecurityPolicy?: ResponseHeadersContentSecurityPolicy;
    /**
     * (experimental) Determines whether CloudFront includes the X-Content-Type-Options HTTP response header with its value set to nosniff.
     *
     * @default - no content type options
     * @experimental
     */
    readonly contentTypeOptions?: ResponseHeadersContentTypeOptions;
    /**
     * (experimental) Determines whether CloudFront includes the X-Frame-Options HTTP response header and the header’s value.
     *
     * @default - no frame options
     * @experimental
     */
    readonly frameOptions?: ResponseHeadersFrameOptions;
    /**
     * (experimental) Determines whether CloudFront includes the Referrer-Policy HTTP response header and the header’s value.
     *
     * @default - no referrer policy
     * @experimental
     */
    readonly referrerPolicy?: ResponseHeadersReferrerPolicy;
    /**
     * (experimental) Determines whether CloudFront includes the Strict-Transport-Security HTTP response header and the header’s value.
     *
     * @default - no strict transport security
     * @experimental
     */
    readonly strictTransportSecurity?: ResponseHeadersStrictTransportSecurity;
    /**
     * (experimental) Determines whether CloudFront includes the X-XSS-Protection HTTP response header and the header’s value.
     *
     * @default - no xss protection
     * @experimental
     */
    readonly xssProtection?: ResponseHeadersXSSProtection;
}
/**
 * (experimental) The policy directives and their values that CloudFront includes as values for the Content-Security-Policy HTTP response header.
 *
 * @experimental
 */
export interface ResponseHeadersContentSecurityPolicy {
    /**
     * (experimental) The policy directives and their values that CloudFront includes as values for the Content-Security-Policy HTTP response header.
     *
     * @experimental
     */
    readonly contentSecurityPolicy: string;
    /**
     * (experimental) A Boolean that determines whether CloudFront overrides the Content-Security-Policy HTTP response header received from the origin with the one specified in this response headers policy.
     *
     * @experimental
     */
    readonly override: boolean;
}
/**
 * (experimental) Determines whether CloudFront includes the X-Content-Type-Options HTTP response header with its value set to nosniff.
 *
 * @experimental
 */
export interface ResponseHeadersContentTypeOptions {
    /**
     * (experimental) A Boolean that determines whether CloudFront overrides the X-Content-Type-Options HTTP response header received from the origin with the one specified in this response headers policy.
     *
     * @experimental
     */
    readonly override: boolean;
}
/**
 * (experimental) Determines whether CloudFront includes the X-Frame-Options HTTP response header and the header’s value.
 *
 * @experimental
 */
export interface ResponseHeadersFrameOptions {
    /**
     * (experimental) The value of the X-Frame-Options HTTP response header.
     *
     * @experimental
     */
    readonly frameOption: HeadersFrameOption;
    /**
     * (experimental) A Boolean that determines whether CloudFront overrides the X-Frame-Options HTTP response header received from the origin with the one specified in this response headers policy.
     *
     * @experimental
     */
    readonly override: boolean;
}
/**
 * (experimental) Determines whether CloudFront includes the Referrer-Policy HTTP response header and the header’s value.
 *
 * @experimental
 */
export interface ResponseHeadersReferrerPolicy {
    /**
     * (experimental) The value of the Referrer-Policy HTTP response header.
     *
     * @experimental
     */
    readonly referrerPolicy: HeadersReferrerPolicy;
    /**
     * (experimental) A Boolean that determines whether CloudFront overrides the Referrer-Policy HTTP response header received from the origin with the one specified in this response headers policy.
     *
     * @experimental
     */
    readonly override: boolean;
}
/**
 * (experimental) Determines whether CloudFront includes the Strict-Transport-Security HTTP response header and the header’s value.
 *
 * @experimental
 */
export interface ResponseHeadersStrictTransportSecurity {
    /**
     * (experimental) A number that CloudFront uses as the value for the max-age directive in the Strict-Transport-Security HTTP response header.
     *
     * @experimental
     */
    readonly accessControlMaxAge: Duration;
    /**
     * (experimental) A Boolean that determines whether CloudFront includes the includeSubDomains directive in the Strict-Transport-Security HTTP response header.
     *
     * @default false
     * @experimental
     */
    readonly includeSubdomains?: boolean;
    /**
     * (experimental) A Boolean that determines whether CloudFront overrides the Strict-Transport-Security HTTP response header received from the origin with the one specified in this response headers policy.
     *
     * @experimental
     */
    readonly override: boolean;
    /**
     * (experimental) A Boolean that determines whether CloudFront includes the preload directive in the Strict-Transport-Security HTTP response header.
     *
     * @default false
     * @experimental
     */
    readonly preload?: boolean;
}
/**
 * (experimental) Determines whether CloudFront includes the X-XSS-Protection HTTP response header and the header’s value.
 *
 * @experimental
 */
export interface ResponseHeadersXSSProtection {
    /**
     * (experimental) A Boolean that determines whether CloudFront includes the mode=block directive in the X-XSS-Protection header.
     *
     * @default false
     * @experimental
     */
    readonly modeBlock?: boolean;
    /**
     * (experimental) A Boolean that determines whether CloudFront overrides the X-XSS-Protection HTTP response header received from the origin with the one specified in this response headers policy.
     *
     * @experimental
     */
    readonly override: boolean;
    /**
     * (experimental) A Boolean that determines the value of the X-XSS-Protection HTTP response header.
     *
     * When this setting is true, the value of the X-XSS-Protection header is 1.
     * When this setting is false, the value of the X-XSS-Protection header is 0.
     *
     * @experimental
     */
    readonly protection: boolean;
    /**
     * (experimental) A reporting URI, which CloudFront uses as the value of the report directive in the X-XSS-Protection header.
     *
     * You cannot specify a ReportUri when ModeBlock is true.
     *
     * @default - no report uri
     * @experimental
     */
    readonly reportUri?: string;
}
/**
 * (experimental) Enum representing possible values of the X-Frame-Options HTTP response header.
 *
 * @experimental
 */
export declare enum HeadersFrameOption {
    /**
     * (experimental) The page can only be displayed in a frame on the same origin as the page itself.
     *
     * @experimental
     */
    DENY = "DENY",
    /**
     * (experimental) The page can only be displayed in a frame on the specified origin.
     *
     * @experimental
     */
    SAMEORIGIN = "SAMEORIGIN"
}
/**
 * (experimental) Enum representing possible values of the Referrer-Policy HTTP response header.
 *
 * @experimental
 */
export declare enum HeadersReferrerPolicy {
    /**
     * (experimental) The referrer policy is not set.
     *
     * @experimental
     */
    NO_REFERRER = "no-referrer",
    /**
     * (experimental) The referrer policy is no-referrer-when-downgrade.
     *
     * @experimental
     */
    NO_REFERRER_WHEN_DOWNGRADE = "no-referrer-when-downgrade",
    /**
     * (experimental) The referrer policy is origin.
     *
     * @experimental
     */
    ORIGIN = "origin",
    /**
     * (experimental) The referrer policy is origin-when-cross-origin.
     *
     * @experimental
     */
    ORIGIN_WHEN_CROSS_ORIGIN = "origin-when-cross-origin",
    /**
     * (experimental) The referrer policy is same-origin.
     *
     * @experimental
     */
    SAME_ORIGIN = "same-origin",
    /**
     * (experimental) The referrer policy is strict-origin.
     *
     * @experimental
     */
    STRICT_ORIGIN = "strict-origin",
    /**
     * (experimental) The referrer policy is strict-origin-when-cross-origin.
     *
     * @experimental
     */
    STRICT_ORIGIN_WHEN_CROSS_ORIGIN = "strict-origin-when-cross-origin",
    /**
     * (experimental) The referrer policy is unsafe-url.
     *
     * @experimental
     */
    UNSAFE_URL = "unsafe-url"
}
